package com.yunzhi.marketing.xlk.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.marketing.base.BaseController;
import com.yunzhi.marketing.base.ResponseBean;
import com.yunzhi.marketing.xlk.entity.CustomerSubscribe;
import com.yunzhi.marketing.xlk.service.ICustomerSubscribeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    * 客户认购单  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2021-07-30
 */
@RestController
@RequestMapping("/api")
@Api(value = "", tags = "xlk-")
public class CustomerSubscribeController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(CustomerSubscribeController.class);

    @Autowired
    public ICustomerSubscribeService iCustomerSubscribeService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @ApiOperation(value = "", notes = "")
    @RequestMapping(value="/customerSubscribe",method= RequestMethod.GET)
    public ResponseBean customerSubscribeList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                              @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                              @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<CustomerSubscribe> pg = new Page<>(pageNum, pageSize);
            LambdaQueryWrapper<CustomerSubscribe> queryWrapper = new LambdaQueryWrapper<>();
            queryWrapper.eq(CustomerSubscribe::getOrgId,getOrgId(request));
            queryWrapper.orderByDesc(CustomerSubscribe::getCreateDate);

            IPage<CustomerSubscribe> result = iCustomerSubscribeService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("customerSubscribeList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param customerSubscribe 实体对象
     * @return
     */
    @ApiOperation(value = "", notes = "")
    @RequestMapping(value="/customerSubscribe",method= RequestMethod.POST)
    public ResponseBean customerSubscribeAdd(@RequestBody CustomerSubscribe customerSubscribe, @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iCustomerSubscribeService.save(customerSubscribe)){
                responseBean.addSuccess(customerSubscribe);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("customerSubscribeAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ApiOperation(value = "", notes = "")
    @ResponseBody
    @RequestMapping(value="/customerSubscribe/{id}", method= RequestMethod.DELETE)
    public ResponseBean customerSubscribeDelete(@PathVariable String id, @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iCustomerSubscribeService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("customerSubscribeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param customerSubscribe 实体对象
     * @return
     */
    @ApiOperation(value = "", notes = "")
    @RequestMapping(value="/customerSubscribe/{id}",method= RequestMethod.PUT)
    public ResponseBean customerSubscribeUpdate(@PathVariable String id,
                                                @RequestBody CustomerSubscribe customerSubscribe, @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iCustomerSubscribeService.updateById(customerSubscribe)){
                responseBean.addSuccess(customerSubscribe);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("customerSubscribeUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @ApiOperation(value = "", notes = "")
    @RequestMapping(value="/customerSubscribe/{id}",method= RequestMethod.GET)
    public ResponseBean customerSubscribeGet(@PathVariable String id, @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iCustomerSubscribeService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("customerSubscribeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
